#[non_exhaustive]#[repr(u8)]pub enum BoltDeviceKind {
Unknown = 0,
Keyboard = 1,
Mouse = 2,
Numpad = 3,
Presenter = 4,
Remote = 7,
Trackball = 8,
Touchpad = 9,
Tablet = 10,
Gamepad = 11,
Joystick = 12,
Headset = 13,
}Expand description
Represents the kind of a device paired to a Bolt receiver.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown = 0
Unknown device kind — also the fold target for values this crate does not model (kind is identity-only and must never drop an event).
Keyboard = 1
Keyboard device.
Mouse = 2
Mouse device.
Numpad = 3
Numeric keypad device.
Presenter = 4
Presenter device.
Remote = 7
Remote-control device.
Trackball = 8
Trackball device.
Touchpad = 9
Touchpad device.
Tablet = 10
Tablet device.
Gamepad = 11
Gamepad device.
Joystick = 12
Joystick device.
Headset = 13
Headset device.