pub enum ReprogControlsEvent {
DivertedButtons([ControlId; 4]),
DivertedRawMouseXy {
dx: i16,
dy: i16,
},
AnalyticsKeyEvents([AnalyticsKeyEvent; 5]),
DivertedRawWheel {
resolution: RawWheelResolution,
periods: U4,
delta_vertical: i16,
},
}Expand description
Event emitted by 0x1b04.
Variants
DivertedButtons([ControlId; 4])
Up to four currently pressed diverted controls.
DivertedRawMouseXy
Raw pointer movement reported while a diverted control is held.
AnalyticsKeyEvents([AnalyticsKeyEvent; 5])
Batch of analytics key event entries.
DivertedRawWheel
Raw wheel movement reported while a diverted control is held.
Implementations
Sourceimpl ReprogControlsEvent
impl ReprogControlsEvent
Sourcepub fn is_pressed(self, cid: ControlId) -> bool
pub fn is_pressed(self, cid: ControlId) -> bool
Whether cid is currently reported as pressed in a diverted-buttons event.