run_host_switch_session

Function run_host_switch_session 

pub async fn run_host_switch_session(
    keyboard: DeviceRoute,
    shutdown: Receiver<HostSwitchStopReason>,
    channel_pool: ChannelPool,
) -> Result<Option<u8>, HostSwitchError>
Capture host switch keys on keyboard until one is pressed or shutdown resolves. Controls are restored before a requested host is returned.